/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.core.util;

public final class ComparablePair<A extends Comparable<A>,B extends Comparable<B>> extends Pair<A,B>
    implements Comparable<ComparablePair<A,B>> {

  public ComparablePair(A f, B s) {
    super(f, s);
  }

  @Override
  public int compareTo(ComparablePair<A,B> abPair) {
    int cmp = getFirst().compareTo(abPair.getFirst());
    if (cmp == 0) {
      cmp = getSecond().compareTo(abPair.getSecond());
    }

    return cmp;
  }

}
